//	AudioSettings.cpp - Window displaying the app's audio settings.
//	----------------------------------------------------------------------------
//	This file is part of OSC2VST, a simple OSC-aware VSTi host.
//	Copyright (c) 2009 Niall Moody.
//
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "AudioSettings.h"
#include "TrayIcon.h"

//------------------------------------------------------------------------------
AudioSettingsComponent::AudioSettingsComponent(AudioDeviceManager *deviceManager,
											   TrayIcon *icon):
Component(),
trayIcon(icon)
{
	String tempstr;

	audioSettings = new AudioDeviceSelectorComponent(*deviceManager,
													 0,
													 0,
													 2,
													 2,
													 false,
													 false);
	audioSettings->setBounds(0, 0, 350, 140);
	addAndMakeVisible(audioSettings);

	portLabel = new Label(T("OSC Port:"), T("OSC Port:"));
	portLabel->setBounds(10, 140, 65, 24);
	addAndMakeVisible(portLabel);

	portEditor = new TextEditor();
	tempstr << trayIcon->getPort();
	portEditor->setText(tempstr, false);
	portEditor->setBounds(75, 140, 265, 24);
	portEditor->setInputRestrictions(0, T("0123456789"));
	portEditor->addListener(this);
	addAndMakeVisible(portEditor);
}

//------------------------------------------------------------------------------
AudioSettingsComponent::~AudioSettingsComponent()
{
	deleteAllChildren();
}

//------------------------------------------------------------------------------
void AudioSettingsComponent::textEditorTextChanged(TextEditor& editor)
{
	trayIcon->setPort(portEditor->getText().getIntValue());
}
