//	ParameterList.cpp - Window displaying the parameters available via OSC.
//	----------------------------------------------------------------------------
//	This file is part of OSC2VST, a simple OSC-aware VSTi host.
//	Copyright (c) 2009 Niall Moody.
//
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ParameterList.h"

//------------------------------------------------------------------------------
ParameterList::ParameterList(AudioPluginInstance *plugin):
Component()
{
	int i;
	Label *l;
	int y = 10;

	//First, the host commands, which won't change.
	l = new Label(T("Host Commands"), T("Host Commands:"));
	l->setFont(Font(14.0f, Font::bold));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	l = new Label(T("Quit"), T("/quit: Quits OSC2VST."));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	l = new Label(T("Load Plugin"), T("/loadPlugin <path (string)>: Replaces the current plugin."));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	l = new Label(T("Note On"), T("/noteOn <note (int) vel (float)>: Triggers a note for the plugin."));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	l = new Label(T("Note Off"), T("/noteOff <note (int)>: Stops a note for the plugin."));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	l = new Label(T("MIDI"), T("/MIDI <byte1 byte2 byte3 (int)>: Sends a MIDI message to the plugin."));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 30;

	//Next, add all the plugin's parameters.
	l = new Label(T("Plugin Parameters"), T("Plugin Parameters:"));
	l->setFont(Font(14.0f, Font::bold));
	l->setBounds(10, y, 360, 20);
	addAndMakeVisible(l);
	y += 20;

	for(i=0;i<plugin->getNumParameters();++i)
	{
		String tempName;
		String tempParam;
		String tempstr;

		tempName << T("param ") << i;
		tempstr = plugin->getParameterName(i);
		tempstr = tempstr.removeCharacters(T(" #*,/?[]{}"));
		tempParam << T("/") << tempstr << " <float value>";

		l = new Label(tempName, tempParam);
		l->setBounds(10, y, 360, 20);
		addAndMakeVisible(l);
		y += 20;
	}

	setSize(380, y+10);
}

//------------------------------------------------------------------------------
ParameterList::~ParameterList()
{
	deleteAllChildren();
}
