//	PluginWindow.cpp - Window displaying the plugin's editor.
//	----------------------------------------------------------------------------
//	This file is part of OSC2VST, a simple OSC-aware VSTi host.
//	Copyright (c) 2009 Niall Moody.
//
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "PluginWindow.h"
#include "TrayIcon.h"

//------------------------------------------------------------------------------
PluginWindow::PluginWindow(AudioPluginInstance *p, TrayIcon *o):
DocumentWindow(p->getName(), Colour(0xFFEEECE1), DocumentWindow::closeButton),
plugin(p),
owner(o)
{
	AudioProcessorEditor *editor = 0;

	setUsingNativeTitleBar(true);
	setDropShadowEnabled(false);
	centreWithSize(400, 300);

	editor = plugin->createEditorIfNeeded();
	if(editor == 0)
		editor = new GenericAudioProcessorEditor(plugin);
	if(editor != 0)
		setContentComponent(editor, true, true);
	else
	{
		AlertWindow::showMessageBox(AlertWindow::WarningIcon,
                                    T("Plugin error"),
                                    T("Could not generate plugin editor."));
	}

    setVisible (true);
}

//------------------------------------------------------------------------------
PluginWindow::~PluginWindow()
{
	owner->editorClosed();

	//Probably not necessary?
	setContentComponent(0);
}

//------------------------------------------------------------------------------
void PluginWindow::closeButtonPressed()
{
	delete this;
}
