//	TrayIcon.h - Where the app does all its work.
//	----------------------------------------------------------------------------
//	This file is part of OSC2VST, a simple OSC-aware VSTi host.
//	Copyright (c) 2009 Niall Moody.
//
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TRAYICON_H_
#define TRAYICON_H_

//Stupid MSVC v6 warning about the STL...
#ifdef WIN32
#pragma warning(disable:4786)
#endif

#include "NiallsSocketLib/UDPSocket.h"
#include "BranchesLAF.h"

#include <map>
#include <string>

class PluginWindow;
namespace OSC
{
	class Message;
	class Bundle;
};

///	Where the app does all its work.
class TrayIcon : public SystemTrayIconComponent,
				 public Thread,
				 public Timer
{
  public:
	///	Constructor.
	TrayIcon(const String& commandLine);
	///	Destructor.
	~TrayIcon();

	///	So we can pop up a menu on right click.
	void mouseUp(const MouseEvent& e);

	///	Where the program listens for OSC messages.
	void run();
	///	We need to load plugins from the main thread, so use a timer for that.
	/*!
		(I don't know why this is necessary, but I get exceptions in the
		 debugger otherwise...)
	 */
	void timerCallback();

	///	Changes which port we listen on.
	void setPort(int16_t p);
	///	Returns the current port we're listening on.
	int16_t getPort() const {return newPort;};
	///	So we know when the user's closed the plugin's editor window.
	void editorClosed();

	juce_UseDebuggingNewOperator
  private:
	///	Helper method to load a plugin from a file.
	void loadPlugin(const String& path);
	///	Helper method to handle an OSC message.
	void handleMessage(OSC::Message& message);
	///	Helper method to handle an OSC bundle.
	void handleBundle(OSC::Bundle& bundle);

	///	Helper method to get the AudioSettings file.
	File getAudioSettingsFile() const;
	///	Helper method to load the AudioSettings file and initialise the device manager.
	void initialiseAudio();
	///	Helper method to save to the AudioSettings file.
	void saveAudioSettings();

	///	The icon to be displayed in the task bar.
	Image *icon;

	///	The plugin instance.
	AudioPluginInstance *plugin;
	///	Processes the plugin's audio.
	AudioProcessorPlayer pluginPlayer;
	///	Handles the sound output.
	AudioDeviceManager deviceManager;
	///	Editor window for the plugin.
	PluginWindow *pluginWindow;
	///	The plugin's parameter indices mapped to their OSC addresses.
	std::map<std::string, int> parameters;
	///	Used to load a new plugin.
	String newPlugin;

	///	The socket to listen for OSC messages on.
	UDPSocket socket;
	///	Used to change the port we're listening on.
	int16_t newPort;

	///	Different LookAndFeel to JUCE's default.
	BranchesLAF * laf;
};

#endif
