//	MainPanel.cpp - Window holding the various widgets.
//	----------------------------------------------------------------------------

#include "MainPanel.h"
#include "NiallsOSCLib/OSCMessage.h"

//------------------------------------------------------------------------------
MainPanel::MainPanel():
Component()
{
	slider = new Slider(T("Slider"));
	slider->setSliderStyle(Slider::LinearHorizontal);
	slider->setRange(0.0, 1.0);
	slider->setBounds(10, 10, 280, 24);
	slider->addListener(this);
	addAndMakeVisible(slider);

	sliderAddress = new TextEditor(T("Slider Address"));
	sliderAddress->setText(T("/FrqOSht"));
	sliderAddress->setBounds(10, 38, 280, 24);
	addAndMakeVisible(sliderAddress);

	keyboard = new MidiKeyboardComponent(midiState, MidiKeyboardComponent::horizontalKeyboard);
	keyboard->setBounds(10, 78, 280, 80);
	//Make it possible to play it with the computer keyboard.
	keyboard->setKeyPressForNote(KeyPress('z', ModifierKeys(), 'z'), 0);
	keyboard->setKeyPressForNote(KeyPress('s', ModifierKeys(), 's'), 1);
	keyboard->setKeyPressForNote(KeyPress('x', ModifierKeys(), 'x'), 2);
	keyboard->setKeyPressForNote(KeyPress('d', ModifierKeys(), 'd'), 3);
	keyboard->setKeyPressForNote(KeyPress('c', ModifierKeys(), 'c'), 4);
	keyboard->setKeyPressForNote(KeyPress('v', ModifierKeys(), 'v'), 5);
	keyboard->setKeyPressForNote(KeyPress('g', ModifierKeys(), 'g'), 6);
	keyboard->setKeyPressForNote(KeyPress('b', ModifierKeys(), 'b'), 7);
	keyboard->setKeyPressForNote(KeyPress('h', ModifierKeys(), 'h'), 8);
	keyboard->setKeyPressForNote(KeyPress('n', ModifierKeys(), 'n'), 9);
	keyboard->setKeyPressForNote(KeyPress('j', ModifierKeys(), 'j'), 10);
	keyboard->setKeyPressForNote(KeyPress('m', ModifierKeys(), 'm'), 11);

	keyboard->setKeyPressForNote(KeyPress('q', ModifierKeys(), 'q'), 12);
	keyboard->setKeyPressForNote(KeyPress('2', ModifierKeys(), '2'), 13);
	keyboard->setKeyPressForNote(KeyPress('w', ModifierKeys(), 'w'), 14);
	keyboard->setKeyPressForNote(KeyPress('3', ModifierKeys(), '3'), 15);
	keyboard->setKeyPressForNote(KeyPress('e', ModifierKeys(), 'e'), 16);
	keyboard->setKeyPressForNote(KeyPress('r', ModifierKeys(), 'r'), 17);
	keyboard->setKeyPressForNote(KeyPress('5', ModifierKeys(), '5'), 18);
	keyboard->setKeyPressForNote(KeyPress('t', ModifierKeys(), 't'), 19);
	keyboard->setKeyPressForNote(KeyPress('6', ModifierKeys(), '6'), 20);
	keyboard->setKeyPressForNote(KeyPress('y', ModifierKeys(), 'y'), 21);
	keyboard->setKeyPressForNote(KeyPress('7', ModifierKeys(), '7'), 22);
	keyboard->setKeyPressForNote(KeyPress('u', ModifierKeys(), 'u'), 23);
	keyboard->setKeyPressBaseOctave(4);
	addAndMakeVisible(keyboard);

	loadLabel = new Label(T("Load Plugin:"), T("Load Plugin:"));
	loadLabel->setBounds(10, 158, 280, 24);
	addAndMakeVisible(loadLabel);
	loadPlugin = new FilenameComponent(T("Load Plugin"),
									   File::nonexistent,
									   true,
									   false,
									   false,
									   T("*.dll"),
									   T(""),
									   T(""));
	loadPlugin->setBounds(10, 180, 280, 24);
	loadPlugin->addListener(this);
	addAndMakeVisible(loadPlugin);

	startTimer(30);

	setSize(300, 214);
}

//------------------------------------------------------------------------------
MainPanel::~MainPanel()
{
	stopTimer();
	deleteAllChildren();
}

//------------------------------------------------------------------------------
void MainPanel::sliderValueChanged(Slider *s)
{
	if(s == slider)
	{
		oscOutput.sendParameter((const char *)(sliderAddress->getText()),
								slider->getValue());
	}
}

//------------------------------------------------------------------------------
void MainPanel::filenameComponentChanged(FilenameComponent *f)
{
	String tempPath = f->getCurrentFile().getFullPathName();

	oscOutput.sendLoadPlugin((const char *)tempPath);
}

//------------------------------------------------------------------------------
void MainPanel::timerCallback()
{
	MidiBuffer buffer;
	MidiMessage midi = MidiMessage::noteOn(1, 0, 1.0f);
	int tempint;

	midiState.processNextMidiBuffer(buffer, 0, 1024, true);

	MidiBuffer::Iterator it(buffer);

	while(it.getNextEvent(midi, tempint))
	{
		if(midi.isNoteOn())
			oscOutput.sendNoteOn(midi.getNoteNumber(), 96.0f);
		else if(midi.isNoteOff())
			oscOutput.sendNoteOff(midi.getNoteNumber());
	}
}
