//	MainPanel.h - Window holding the various widgets.
//	----------------------------------------------------------------------------

#ifndef MAINPANEL_H_
#define MAINPANEL_H_

#include "OSCOutput.h"

#include "juce.h"

///	Window holding the various widgets.
class MainPanel : public Component,
				  public SliderListener,
				  public FilenameComponentListener,
				  public Timer
{
  public:
	///	Constructor.
	MainPanel();
	///	Destructor.
	~MainPanel();

	///	So we can send OSC messages when the slider is dragged.
	void sliderValueChanged(Slider *s);
	///	So we can load a new plugin.
	void filenameComponentChanged(FilenameComponent *f);

	///	We need to periodically check the keyboard component for events to transmit.
	void timerCallback();
  private:
	///	Slider for controlling a parameter in the VST hosted by OSC2VST.
	Slider *slider;
	///	Text editor to set the address to send the slider's events to.
	TextEditor *sliderAddress;
	///	Keyboard for sending note on/off events.
	MidiKeyboardComponent *keyboard;
	///	Label for the plugin loader.
	Label *loadLabel;
	///	Component for loading a new plugin.
	FilenameComponent *loadPlugin;

	///	The MIDI state for the keyboard.
	MidiKeyboardState midiState;

	///	Used to send OSC messages.
	OSCOutput oscOutput;
};

#endif
