//	OSCBase.h - Base class for any OSC data packets etc.
//	----------------------------------------------------------------------------

#ifndef OSCBASE_H_
#define OSCBASE_H_

#include <stdint.h>

//Stupid MSVC v6 warning about the STL...
#ifdef WIN32
#pragma warning(disable:4786)
#endif

namespace OSC
{

//------------------------------------------------------------------------------
///	OSC's int32 type.
typedef int32_t Int32;
///	OSC's float32 type (this may be different on other machines?).
typedef float Float32;
///	OSC's OSC-string type.
typedef char * OscString;
///	A padding byte.
typedef char PaddingByte;

//------------------------------------------------------------------------------
///	The base class for any OSC message/bundle packets.
class OscBase
{
  public:
	///	Constructor.
	OscBase() {};
	///	Destructor.
	virtual ~OscBase() {};

	///	Returns the total size of the OSC data to be sent.
	virtual Int32 getSize() = 0;
	///	Returns the data to be sent as a contiguous unsigned char array.
	virtual char *getData() = 0;
};

///	Used to easily access the individual bytes in Int32 and Float32s.
struct GetTheBytes
{
	unsigned char a;
	unsigned char b;
	unsigned char c;
	unsigned char d;
};

}

#endif
