//	OSCOutput.cpp - Class to simplify sending OSC messages.
//	----------------------------------------------------------------------------

#include "OSCOutput.h"
#include "NiallsOSCLib/OSCMessage.h"

using namespace OSC;
using namespace std;

//------------------------------------------------------------------------------
OSCOutput::OSCOutput()
{
	socket.setAddress("127.0.0.1");
	socket.setPort(5678);
}

//------------------------------------------------------------------------------
OSCOutput::~OSCOutput()
{
	
}

//------------------------------------------------------------------------------
void OSCOutput::setAddress(const std::string& address)
{
	socket.setAddress(address);
}

//------------------------------------------------------------------------------
void OSCOutput::setPort(int port)
{
	socket.setPort(port);
}

//------------------------------------------------------------------------------
void OSCOutput::sendQuit()
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/quit");
	//Necessary?
	message.addFloat32(1.0f);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendLoadPlugin(const std::string& path)
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/loadPlugin");
	message.addOscString(path);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendUnloadPlugin()
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/unloadPlugin");
	//Necessary?
	message.addFloat32(1.0f);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendNoteOn(int note, float velocity)
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/noteOn");
	message.addInt32(note);
	message.addFloat32(velocity);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendNoteOff(int note)
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/noteOff");
	message.addInt32(note);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendMIDI(int byte1, int byte2, int byte3)
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress("/MIDI");
	message.addInt32(byte1);
	message.addInt32(byte2);
	message.addInt32(byte3);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}

//------------------------------------------------------------------------------
void OSCOutput::sendParameter(const string& oscAddress, float value)
{
	Message message;
	char *buffer;
	int32_t bufSize;

	message.setAddress(oscAddress);
	message.addFloat32(value);

	bufSize = message.getSize();
	buffer = message.getData();
	socket.sendData(buffer, bufSize);
}
