//	OSCOutput.h - Class to simplify sending OSC messages.
//	----------------------------------------------------------------------------

#ifndef OSCOUTPUT_H_
#define OSCOUTPUT_H_

#include "NiallsSocketLib/UDPSocket.h"

#include <string>

///	Class to simplify sending OSC messages.
/*!
	You probably want to create one of these and then hold on to it, rather
	than creating it every time you want to send a message.
 */
class OSCOutput
{
  public:
	///	Constructor.
	/*!
		Sets default values for the address and port to send to, gets a socket
		from the OS.

		Default address: 127.0.0.1
		Default port: 5678
	 */
	OSCOutput();
	///	Destructor.
	~OSCOutput();

	///	Sets the ip address to send to.
	void setAddress(const std::string& address);
	///	Sets the port to send to.
	void setPort(int port);

	///	Sends a message telling OSC2VST to quit.
	void sendQuit();
	///	Sends a message telling OSC2VST to load a new plugin.
	void sendLoadPlugin(const std::string& path);
	///	Sends a message telling OSC2VST to unload the current plugin.
	void sendUnloadPlugin();
	///	Send a note on event.
	/*!
		\param note The note to trigger (0->127).
		\param velocity How loud to play the note (0->1).
	 */
	void sendNoteOn(int note, float velocity);
	///	Send a note off event.
	void sendNoteOff(int note);
	///	Sends a 3-byte MIDI message as an OSC message.
	void sendMIDI(int byte1, int byte2, int byte3);
	///	Sends a parameter change event.
	/*!
		\param oscAddress The address of the parameter to change.  You can get
		a list of parameter addresses from OSC2VST's right-click menu.
		\param value The value to change the parameter to (0->1).
	 */
	void sendParameter(const std::string& oscAddress, float value);
  private:
	///	The socket to send data out.
	UDPSocket socket;
};

#endif
